/* CAIL - The Clutter Accessibility Implementation Library
 *
 * Copyright (C) 2008 Igalia, S.L.
 *
 * Author: Alejandro Pieiro Iglesias <apinheiro@igalia.com>
 *
 * Some parts are based on GailWidget from GAIL
 * GAIL - The GNOME Accessibility Implementation Library
 * Copyright 2001, 2002, 2003 Sun Microsystems Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef                                         __CAIL_ACTOR_H__
#define                                         __CAIL_ACTOR_H__

#include                                        <atk/atk.h>
#include                                        <clutter/clutter.h>

G_BEGIN_DECLS

#define                                         CAIL_TYPE_ACTOR \
                                                (cail_actor_get_type ())
#define                                         CAIL_ACTOR(obj) \
                                                (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
                                                CAIL_TYPE_ACTOR, CailActor))
#define                                         CAIL_ACTOR_CLASS(klass) \
                                                (G_TYPE_CHECK_CLASS_CAST ((klass), \
                                                CAIL_TYPE_ACTOR, CailActorClass))
#define                                         CAIL_IS_ACTOR(obj) \
                                                (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
                                                CAIL_TYPE_ACTOR))
#define                                         CAIL_IS_ACTOR_CLASS(klass)\
                                                (G_TYPE_CHECK_CLASS_TYPE ((klass), \
                                                CAIL_TYPE_ACTOR))
#define                                         CAIL_ACTOR_GET_CLASS(obj) \
                                                (G_TYPE_INSTANCE_GET_CLASS ((obj), \
                                                CAIL_TYPE_ACTOR, CailActorClass))

typedef struct                                  _CailActor           CailActor;
typedef struct                                  _CailActorClass      CailActorClass;
typedef struct                                  _CailActorPrivate    CailActorPrivate;
typedef struct                                  _CailActorActionInfo CailActorActionInfo;

typedef void (*ACTION_FUNC)                     (CailActor *cail_actor);

struct _CailActorActionInfo
{
  /* GailCell like action management */

  gchar       *name;
  gchar       *description;
  gchar       *keybinding;
  ACTION_FUNC  do_action_func;
};


struct                                          _CailActor
{
  AtkGObjectAccessible parent;

  /* < private > */
  CailActorPrivate *priv;
};

struct                                          _CailActorClass
{
  AtkGObjectAccessibleClass parent_class;

  /* Signal handler for notify signal on Clutter Actor */
  void (*notify_clutter)                        (GObject    *object,
                                                 GParamSpec *pspec);

  gint (*add_actor)                             (ClutterActor *container,
                                                 ClutterActor *actor,
                                                 gpointer     data);

  gint (*remove_actor)                          (ClutterActor *container,
                                                 ClutterActor *actor,
                                                 gpointer     data);

};


GType
cail_actor_get_type                             (void);

AtkObject*
cail_actor_new                                  (ClutterActor *actor);

gboolean
cail_actor_add_action                           (CailActor   *cail_actor,
                                                 const gchar *action_name,
                                                 const gchar *action_description,
                                                 const gchar *action_keybinding,
                                                 ACTION_FUNC  action_func);
gboolean
cail_actor_remove_action                        (CailActor   *cail_actor,
                                                 gint         action_id);

gboolean
cail_actor_remove_action_by_name                (CailActor   *cail_actor,
                                                 const gchar *action_name);


G_END_DECLS

#endif /* __CAIL_ACTOR_H__ */
